==> qtjambi-xmlpatterns-5.15.17-sources.jar: io/qt/xmlpatterns/QXmlName.java <==
package io.qt.xmlpatterns;

import io.qt.*;


/**
 * <p>Represents the name of an XML node, in an efficient, namespace-aware way. QXmlName represents the name of an XML node in a way that is both efficient and safe for comparing names. Normally, an XML node represents an XML element or attribute, but QXmlName can also represent the names of other kinds of nodes, e.g., QAbstractXmlReceiver::processingInstruction() and QAbstractXmlReceiver::namespaceBinding()</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qxmlname.html">QXmlName</a></code></p>
 */
public class QXmlName extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#QXmlName">QXmlName::<wbr>QXmlName()</a></code></p>
     */
    public QXmlName(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlName instance);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#QXmlName-1">QXmlName::<wbr>QXmlName(QXmlNamePool&amp;,<wbr>QString,<wbr>QString,<wbr>QString)</a></code></p>
     */
    public QXmlName(io.qt.xmlpatterns.@StrictNonNull QXmlNamePool namePool, java.lang.@NonNull String localName, java.lang.@NonNull String namespaceURI, java.lang.@NonNull String prefix){
        super((QPrivateConstructor)null);
        java.util.Objects.requireNonNull(namePool, "Argument 'namePool': null not expected.");
        initialize_native(this, namePool, localName, namespaceURI, prefix);
    }
    
    private native static void initialize_native(QXmlName instance, io.qt.xmlpatterns.QXmlNamePool namePool, java.lang.String localName, java.lang.String namespaceURI, java.lang.String prefix);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#QXmlName-2">QXmlName::<wbr>QXmlName(QXmlName)</a></code></p>
     */
    public QXmlName(io.qt.xmlpatterns.@NonNull QXmlName other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QXmlName instance, io.qt.xmlpatterns.QXmlName other);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#isNull">QXmlName::<wbr>isNull()const</a></code></p>
     */
    @QtUninvokable
    public final boolean isNull(){
        return isNull_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isNull_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#localName">QXmlName::<wbr>localName(QXmlNamePool)const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String localName(io.qt.xmlpatterns.@NonNull QXmlNamePool query){
        return localName_native_cref_QXmlNamePool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(query));
    }
    
    @QtUninvokable
    private native java.lang.String localName_native_cref_QXmlNamePool_constfct(long __this__nativeId, long query);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#namespaceUri">QXmlName::<wbr>namespaceUri(QXmlNamePool)const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String namespaceUri(io.qt.xmlpatterns.@NonNull QXmlNamePool query){
        return namespaceUri_native_cref_QXmlNamePool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(query));
    }
    
    @QtUninvokable
    private native java.lang.String namespaceUri_native_cref_QXmlNamePool_constfct(long __this__nativeId, long query);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#operator-eq">QXmlName::<wbr>operator=(QXmlName)</a></code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xmlpatterns.@NonNull QXmlName other){
        assign_native_cref_QXmlName(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QXmlName(long __this__nativeId, long other);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#operator-eq-eq">QXmlName::<wbr>operator==(QXmlName)const</a></code></p>
     */
    @QtUninvokable
    private final boolean operator_equal(io.qt.xmlpatterns.@NonNull QXmlName other){
        return operator_equal_native_cref_QXmlName_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native boolean operator_equal_native_cref_QXmlName_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#prefix">QXmlName::<wbr>prefix(QXmlNamePool)const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String prefix(io.qt.xmlpatterns.@NonNull QXmlNamePool query){
        return prefix_native_cref_QXmlNamePool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(query));
    }
    
    @QtUninvokable
    private native java.lang.String prefix_native_cref_QXmlNamePool_constfct(long __this__nativeId, long query);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#toClarkName">QXmlName::<wbr>toClarkName(QXmlNamePool)const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String toClarkName(io.qt.xmlpatterns.@NonNull QXmlNamePool query){
        return toClarkName_native_cref_QXmlNamePool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(query));
    }
    
    @QtUninvokable
    private native java.lang.String toClarkName_native_cref_QXmlNamePool_constfct(long __this__nativeId, long query);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#fromClarkName">QXmlName::<wbr>fromClarkName(QString,<wbr>QXmlNamePool)</a></code></p>
     */
    public static io.qt.xmlpatterns.@NonNull QXmlName fromClarkName(java.lang.@NonNull String clarkName, io.qt.xmlpatterns.@NonNull QXmlNamePool namePool){
        return fromClarkName_native_cref_QString_cref_QXmlNamePool(clarkName, QtJambi_LibraryUtilities.internal.checkedNativeId(namePool));
    }
    
    private native static io.qt.xmlpatterns.QXmlName fromClarkName_native_cref_QString_cref_QXmlNamePool(java.lang.String clarkName, long namePool);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#isNCName">QXmlName::<wbr>isNCName(QString)</a></code></p>
     */
    public native static boolean isNCName(java.lang.@NonNull String candidate);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QXmlName(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#operator-eq-eq">QXmlName::<wbr>operator==(QXmlName)const</a></code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.xmlpatterns.QXmlName) {
            return operator_equal((io.qt.xmlpatterns.QXmlName) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QXmlName)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QXmlName clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QXmlName clone_native(long __this_nativeId);
    
    /**
     * <p>Overloaded constructor for {@link #QXmlName(io.qt.xmlpatterns.QXmlNamePool, java.lang.String, java.lang.String, java.lang.String)}
     *  with <code>prefix = (String)null</code>.</p>
     */
    public QXmlName(io.qt.xmlpatterns.@StrictNonNull QXmlNamePool namePool, java.lang.@NonNull String localName, java.lang.@NonNull String namespaceURI) {
        this(namePool, localName, namespaceURI, (String)null);
    }
    
    /**
     * <p>Overloaded constructor for {@link #QXmlName(io.qt.xmlpatterns.QXmlNamePool, java.lang.String, java.lang.String, java.lang.String)}</p>
     * <p>with: </p><ul>
     * <li><code>namespaceURI = (String)null</code></li>
     * <li><code>prefix = (String)null</code></li>
     * </ul>
     */
    public QXmlName(io.qt.xmlpatterns.@StrictNonNull QXmlNamePool namePool, java.lang.@NonNull String localName) {
        this(namePool, localName, (String)null, (String)null);
    }
}

==> qtjambi-xmlpatterns-5.15.18-sources.jar: io/qt/xmlpatterns/QXmlName.java <==
package io.qt.xmlpatterns;

import io.qt.*;


/**
 * <p>Represents the name of an XML node, in an efficient, namespace-aware way. QXmlName represents the name of an XML node in a way that is both efficient and safe for comparing names. Normally, an XML node represents an XML element or attribute, but QXmlName can also represent the names of other kinds of nodes, e.g., QAbstractXmlReceiver::processingInstruction() and QAbstractXmlReceiver::namespaceBinding()</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qxmlname.html">QXmlName</a></code></p>
 */
public class QXmlName extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#QXmlName">QXmlName::<wbr/>QXmlName()</a></code></p>
     */
    public QXmlName(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlName instance);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#QXmlName-2">QXmlName::<wbr/>QXmlName(QXmlName)</a></code></p>
     */
    public QXmlName(io.qt.xmlpatterns.@NonNull QXmlName other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QXmlName instance, io.qt.xmlpatterns.QXmlName other);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#QXmlName-1">QXmlName::<wbr/>QXmlName(QXmlNamePool&amp;,<wbr/>QString,<wbr/>QString,<wbr/>QString)</a></code></p>
     */
    public QXmlName(io.qt.xmlpatterns.@StrictNonNull QXmlNamePool namePool, java.lang.@NonNull String localName, java.lang.@NonNull String namespaceURI, java.lang.@NonNull String prefix){
        super((QPrivateConstructor)null);
        java.util.Objects.requireNonNull(namePool, "Argument 'namePool': null not expected.");
        initialize_native(this, namePool, localName, namespaceURI, prefix);
    }
    
    private native static void initialize_native(QXmlName instance, io.qt.xmlpatterns.QXmlNamePool namePool, java.lang.String localName, java.lang.String namespaceURI, java.lang.String prefix);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#isNull">QXmlName::<wbr/>isNull()const</a></code></p>
     */
    @QtUninvokable
    public final boolean isNull(){
        return isNull_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isNull_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#localName">QXmlName::<wbr/>localName(QXmlNamePool)const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String localName(io.qt.xmlpatterns.@NonNull QXmlNamePool query){
        return localName_native_cref_QXmlNamePool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(query));
    }
    
    @QtUninvokable
    private native java.lang.String localName_native_cref_QXmlNamePool_constfct(long __this__nativeId, long query);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#namespaceUri">QXmlName::<wbr/>namespaceUri(QXmlNamePool)const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String namespaceUri(io.qt.xmlpatterns.@NonNull QXmlNamePool query){
        return namespaceUri_native_cref_QXmlNamePool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(query));
    }
    
    @QtUninvokable
    private native java.lang.String namespaceUri_native_cref_QXmlNamePool_constfct(long __this__nativeId, long query);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#operator-eq">QXmlName::<wbr/>operator=(QXmlName)</a></code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xmlpatterns.@NonNull QXmlName other){
        assign_native_cref_QXmlName(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QXmlName(long __this__nativeId, long other);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#operator-eq-eq">QXmlName::<wbr/>operator==(QXmlName)const</a></code></p>
     */
    @QtUninvokable
    public final boolean equals(io.qt.xmlpatterns.@NonNull QXmlName other){
        return equals_native_cref_QXmlName_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native boolean equals_native_cref_QXmlName_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#prefix">QXmlName::<wbr/>prefix(QXmlNamePool)const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String prefix(io.qt.xmlpatterns.@NonNull QXmlNamePool query){
        return prefix_native_cref_QXmlNamePool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(query));
    }
    
    @QtUninvokable
    private native java.lang.String prefix_native_cref_QXmlNamePool_constfct(long __this__nativeId, long query);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#toClarkName">QXmlName::<wbr/>toClarkName(QXmlNamePool)const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String toClarkName(io.qt.xmlpatterns.@NonNull QXmlNamePool query){
        return toClarkName_native_cref_QXmlNamePool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(query));
    }
    
    @QtUninvokable
    private native java.lang.String toClarkName_native_cref_QXmlNamePool_constfct(long __this__nativeId, long query);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#fromClarkName">QXmlName::<wbr/>fromClarkName(QString,<wbr/>QXmlNamePool)</a></code></p>
     */
    public static io.qt.xmlpatterns.@NonNull QXmlName fromClarkName(java.lang.@NonNull String clarkName, io.qt.xmlpatterns.@NonNull QXmlNamePool namePool){
        return fromClarkName_native_cref_QString_cref_QXmlNamePool(clarkName, QtJambi_LibraryUtilities.internal.checkedNativeId(namePool));
    }
    
    private native static io.qt.xmlpatterns.QXmlName fromClarkName_native_cref_QString_cref_QXmlNamePool(java.lang.String clarkName, long namePool);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#isNCName">QXmlName::<wbr/>isNCName(QString)</a></code></p>
     */
    public native static boolean isNCName(java.lang.@NonNull String candidate);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QXmlName(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlname.html#operator-eq-eq">QXmlName::<wbr/>operator==(QXmlName)const</a></code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.xmlpatterns.QXmlName) {
            return equals((io.qt.xmlpatterns.QXmlName) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QXmlName)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QXmlName clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QXmlName clone_native(long __this_nativeId);
    
    /**
     * <p>Overloaded constructor for {@link #QXmlName(io.qt.xmlpatterns.QXmlNamePool, java.lang.String, java.lang.String, java.lang.String)}
     *  with <code>prefix = (String)null</code>.</p>
     */
    public QXmlName(io.qt.xmlpatterns.@StrictNonNull QXmlNamePool namePool, java.lang.@NonNull String localName, java.lang.@NonNull String namespaceURI) {
        this(namePool, localName, namespaceURI, (String)null);
    }
    
    /**
     * <p>Overloaded constructor for {@link #QXmlName(io.qt.xmlpatterns.QXmlNamePool, java.lang.String, java.lang.String, java.lang.String)}</p>
     * <p>with: </p><ul>
     * <li><code>namespaceURI = (String)null</code></li>
     * <li><code>prefix = (String)null</code></li>
     * </ul>
     */
    public QXmlName(io.qt.xmlpatterns.@StrictNonNull QXmlNamePool namePool, java.lang.@NonNull String localName) {
        this(namePool, localName, (String)null, (String)null);
    }
}
